@@ -30,4 +30,8 @@ spkernel2d <- function(pts, poly, h0, grd, kernel = "quartic") {
     res
 }
 
-
+.sp_lt_0.9 <- function() {
+    sI <- sessionInfo(package="sp")
+    spver <- sI$otherPkgs$sp$Version
+    as.numeric(substring(spver, 1, 3)) < 0.9
+}
